@@ -4,8 +4,19 @@ from requests.exceptions import RequestException
 from typing import Callable, Any
 from schematics.models import Model, ValidationError
 from schematics.exceptions import BaseError
-from schematics.types import StringType, DecimalType, IntType, DictType, ListType, URLType, FloatType, \
-    UUIDType, ModelType, BooleanType, UnionType
+from schematics.types import (
+    StringType,
+    DecimalType,
+    IntType,
+    DictType,
+    ListType,
+    URLType,
+    FloatType,
+    UUIDType,
+    ModelType,
+    BooleanType,
+    UnionType,
+)
 
 from basemodels.manifest.data.groundtruth import validate_groundtruth_entry
 from basemodels.manifest.data.taskdata import validate_taskdata_entry
@@ -34,22 +45,22 @@ def validate_request_type(self, data, value):
     multi_challenge should always have multi_challenge_manifests
     """
     # validation runs before other params, so need to handle missing case
-    if not data.get('request_type'):
+    if not data.get("request_type"):
         raise ValidationError("request_type missing")
 
-    if data.get('request_type') == 'multi_challenge':
-        if not data.get('multi_challenge_manifests'):
+    if data.get("request_type") == "multi_challenge":
+        if not data.get("multi_challenge_manifests"):
             raise ValidationError("multi_challenge requires multi_challenge_manifests.")
-    elif data.get('request_type') in ['image_label_multiple_choice', 'image_label_area_select']:
-        if data.get('multiple_choice_min_choices', 1) > data.get('multiple_choice_max_choices', 1):
-            raise ValidationError(
-                "multiple_choice_min_choices cannot be greater than multiple_choice_max_choices")
+    elif data.get("request_type") in ["image_label_multiple_choice", "image_label_area_select"]:
+        if data.get("multiple_choice_min_choices", 1) > data.get("multiple_choice_max_choices", 1):
+            raise ValidationError("multiple_choice_min_choices cannot be greater than multiple_choice_max_choices")
 
     return value
 
 
 class Webhook(Model):
-    """ Model for webhook configuration """
+    """Model for webhook configuration"""
+
     webhook_id = UUIDType(required=True)
     chunk_completed = ListType(StringType(), required=False)
     job_completed = ListType(StringType(), required=False)
@@ -61,7 +72,8 @@ class Webhook(Model):
 
 
 class TaskData(Model):
-    """ objects within taskdata list in Manifest """
+    """objects within taskdata list in Manifest"""
+
     task_key = UUIDType(required=True)
     datapoint_uri = URLType()
     datapoint_hash = StringType(required=True, min_length=10)
@@ -73,15 +85,16 @@ class TaskData(Model):
 
         Raise error if no datapoint_text and no value for URI or if length of URI less than 10.
         """
-        if not value and not data.get('datapoint_text'):
+        if not value and not data.get("datapoint_text"):
             raise ValidationError("datapoint_uri is missing.")
-        if value and len(value) < 10 and not data.get('datapoint_text'):
+        if value and len(value) < 10 and not data.get("datapoint_text"):
             raise ValidationError("datapoint_uri length is less than 10")
         return value
 
 
 class RequestConfig(Model):
-    """ definition of the request_config object in manifest """
+    """definition of the request_config object in manifest"""
+
     version = IntType(default=0)
     shape_type = StringType(choices=["point", "bounding_box", "polygon"])
     min_points = IntType()
@@ -102,7 +115,8 @@ class RequestConfig(Model):
 
 
 class InternalConfig(Model):
-    """ discarded from incoming manifests """
+    """discarded from incoming manifests"""
+
     exchange = DictType(StringType, UnionType([StringType, IntType, FloatType]))
     reco = DictType(StringType, UnionType([StringType, IntType, FloatType]))
     repo = DictType(StringType, UnionType([StringType, IntType, FloatType]))
@@ -121,7 +135,8 @@ class InternalConfig(Model):
 
 
 class NestedManifest(Model):
-    """ The nested manifest description for multi_challenge jobs """
+    """The nested manifest description for multi_challenge jobs"""
+
     job_id = UUIDType(default=uuid.uuid4)
 
     requester_restricted_answer_set = DictType(DictType(StringType))
@@ -130,13 +145,13 @@ class NestedManifest(Model):
         """image_label_area_select should always have a single RAS set"""
 
         # validation runs before other params, so need to handle missing case
-        if not data.get('request_type'):
+        if not data.get("request_type"):
             raise ValidationError("request_type missing")
 
-        if data['request_type'] == 'image_label_area_select':
+        if data["request_type"] == "image_label_area_select":
             if not value or len(value.keys()) == 0:
-                value = {'label': {}}
-                data['requester_restricted_answer_set'] = value
+                value = {"label": {}}
+                data["requester_restricted_answer_set"] = value
         return value
 
     requester_description = StringType()
@@ -146,20 +161,22 @@ class NestedManifest(Model):
 
     requester_question_example = UnionType((URLType, ListType), field=URLType)
 
+    requester_example_extra_fields = UnionType([DictType(StringType), ListType(DictType(StringType))], required=False)
+
     def validate_requester_question_example(self, data, value):
         # validation runs before other params, so need to handle missing case
-        if not data.get('request_type'):
+        if not data.get("request_type"):
             raise ValidationError("request_type missing")
 
         # based on https://github.com/hCaptcha/hmt-basemodels/issues/27#issuecomment-590706643
-        supports_lists = ['image_label_area_select', 'image_label_binary']
+        supports_lists = ["image_label_area_select", "image_label_binary"]
 
-        if isinstance(value, list) and not data['request_type'] in supports_lists:
+        if isinstance(value, list) and not data["request_type"] in supports_lists:
             raise ValidationError("Lists are not allowed in this challenge type")
         return value
 
     unsafe_content = BooleanType(default=False)
-    requester_accuracy_target = FloatType(default=.1)
+    requester_accuracy_target = FloatType(default=0.1)
     request_type = StringType(required=True, choices=BASE_JOB_TYPES)
     validate_request_type = validate_request_type
 
@@ -169,9 +186,8 @@ class NestedManifest(Model):
     groundtruth_uri = URLType(required=False)
     groundtruth = StringType(required=False)
 
-
     def validate_groundtruth(self, data, value):
-        if data.get('groundtruth_uri') and data.get('groundtruth'):
+        if data.get("groundtruth_uri") and data.get("groundtruth"):
             raise ValidationError("Specify only groundtruth_uri or groundtruth, not both.")
         return value
 
@@ -182,27 +198,32 @@ class NestedManifest(Model):
 
 
 class Manifest(Model):
-    """ The manifest description. """
+    """The manifest description."""
+
     job_mode = StringType(required=True, choices=["batch", "online", "instant_delivery"])
     job_api_key = UUIDType(default=uuid.uuid4)
     job_id = UUIDType(default=uuid.uuid4)
     job_total_tasks = IntType(required=True)
     network = StringType(required=False)
-    only_sign_results = BooleanType(default=False,)
-    public_results = BooleanType(default=False,)
+    only_sign_results = BooleanType(
+        default=False,
+    )
+    public_results = BooleanType(
+        default=False,
+    )
 
     requester_restricted_answer_set = DictType(DictType(StringType))
 
     def validate_requester_restricted_answer_set(self, data, value):
         """image_label_area_select should always have a single RAS set"""
         # validation runs before other params, so need to handle missing case
-        if not data.get('request_type'):
+        if not data.get("request_type"):
             raise ValidationError("request_type missing")
 
-        if data['request_type'] == 'image_label_area_select':
+        if data["request_type"] == "image_label_area_select":
             if not value or len(value.keys()) == 0:
-                value = {'label': {}}
-                data['requester_restricted_answer_set'] = value
+                value = {"label": {}}
+                data["requester_restricted_answer_set"] = value
         return value
 
     requester_description = StringType()
@@ -212,15 +233,17 @@ class Manifest(Model):
 
     requester_question_example = UnionType((URLType, ListType), field=URLType)
 
+    requester_example_extra_fields = UnionType([DictType(StringType), ListType(DictType(StringType))])
+
     def validate_requester_question_example(self, data, value):
         # validation runs before other params, so need to handle missing case
-        if not data.get('request_type'):
+        if not data.get("request_type"):
             raise ValidationError("request_type missing")
 
         # based on https://github.com/hCaptcha/hmt-basemodels/issues/27#issuecomment-590706643
-        supports_lists = ['image_label_area_select', 'image_label_binary']
+        supports_lists = ["image_label_area_select", "image_label_binary"]
 
-        if isinstance(value, list) and not data['request_type'] in supports_lists:
+        if isinstance(value, list) and not data["request_type"] in supports_lists:
             raise ValidationError("Lists are not allowed in this challenge type")
         return value
 
@@ -228,11 +251,11 @@ class Manifest(Model):
     task_bid_price = DecimalType(required=True)
     oracle_stake = DecimalType(required=True)
     expiration_date = IntType()
-    requester_accuracy_target = FloatType(default=.1)
+    requester_accuracy_target = FloatType(default=0.1)
     manifest_smart_bounty_addr = StringType()
     hmtoken_addr = StringType()
-    minimum_trust_server = FloatType(default=.1)
-    minimum_trust_client = FloatType(default=.1)
+    minimum_trust_server = FloatType(default=0.1)
+    minimum_trust_client = FloatType(default=0.1)
     recording_oracle_addr = StringType(required=True)
     reputation_oracle_addr = StringType(required=True)
     reputation_agent_addr = StringType(required=True)
@@ -265,7 +288,7 @@ class Manifest(Model):
     rejected_count = IntType(default=0, required=False)
 
     def validate_groundtruth(self, data, value):
-        if data.get('groundtruth_uri') and data.get('groundtruth'):
+        if data.get("groundtruth_uri") and data.get("groundtruth"):
             raise ValidationError("Specify only groundtruth_uri or groundtruth, not both.")
         return value
 
@@ -278,9 +301,12 @@ class Manifest(Model):
     restricted_audience = ModelType(RestrictedAudience, required=True, default={})
 
     def validate_taskdata_uri(self, data, value):
-        if data.get('taskdata') and len(data.get('taskdata')) > 0 and data.get('taskdata_uri'):
-            raise ValidationError(u'Specify only one of taskdata {} or taskdata_uri {}'.format(
-                data.get('taskdata'), data.get('taskdata_uri')))
+        if data.get("taskdata") and len(data.get("taskdata")) > 0 and data.get("taskdata_uri"):
+            raise ValidationError(
+                "Specify only one of taskdata {} or taskdata_uri {}".format(
+                    data.get("taskdata"), data.get("taskdata_uri")
+                )
+            )
         return value
 
     validate_taskdata = validate_taskdata_uri
@@ -316,12 +342,12 @@ def traverse_json_entries(data: Any, callback: Callable, validate_image_content_
 
 
 def validate_manifest_uris(manifest: dict):
-    """ Fetch & validate manifest's remote objects """
+    """Fetch & validate manifest's remote objects"""
 
-    request_type = manifest.get('request_type', '')
+    request_type = manifest.get("request_type", "")
     entry_validators = {
         "groundtruth_uri": lambda k, v, validate: validate_groundtruth_entry(k, v, request_type, validate),
-        "taskdata_uri": lambda _, v, validate: validate_taskdata_entry(v, validate)
+        "taskdata_uri": lambda _, v, validate: validate_taskdata_entry(v, validate),
     }
 
     for uri_key, validate_entry in entry_validators.items():
