@@ -10,15 +10,18 @@ from basemodels.constants import SUPPORTED_CONTENT_TYPES
 
 def create_wrapper_model(type):
     class WrapperModel(BaseModel):
-            data: Optional[type]
-            class Config:
-                    arbitrary_types_allowed = True
-    
+        data: Optional[type]
+
+        class Config:
+            arbitrary_types_allowed = True
+
     return WrapperModel
 
+
 def validate_wrapper_model(Model, data):
     Model.validate({"data": data})
 
+
 groundtruth_entry_key_type = HttpUrl
 GroundtruthEntryKeyModel = create_wrapper_model(groundtruth_entry_key_type)
 """
@@ -78,12 +81,12 @@ ILASGroundtruthEntryModel = create_wrapper_model(ilas_groundtruth_entry_type)
 groundtruth_entry_models_map = {
     "image_label_binary": ILBGroundtruthEntryModel,
     "image_label_multiple_choice": ILMCGroundtruthEntryModel,
-    "image_label_area_select": ILASGroundtruthEntryModel
+    "image_label_area_select": ILASGroundtruthEntryModel,
 }
 
 
 def validate_content_type(uri: str) -> None:
-    """ Validate uri content type """
+    """Validate uri content type"""
     try:
         response = requests.head(uri)
         response.raise_for_status()
@@ -104,7 +107,7 @@ def validate_groundtruth_entry(
     request_type: str,
     validate_image_content_type: bool,
 ):
-    """ Validate key & value of groundtruth entry based on request_type """
+    """Validate key & value of groundtruth entry based on request_type"""
     GroundtruthEntryValueModel = groundtruth_entry_models_map.get(request_type)
 
     if GroundtruthEntryValueModel is None:
